#!/bin/bash

if [[ `whoami` != "root" ]]; then
  echo "Please run installation script as root"
  echo "Installation terminated"
  exit
fi

which ldd >/dev/null 2>>/dev/null
if [ "$?" != "0" ]; then
  echo "No 'ldd' command"
  echo "Installation terminated"
  exit
fi

D=`dirname $0`

T=`ldd $D/opt/sauris/bin/sau_proxy | grep "not found"`
if [ -n "$T" ]; then
  echo "Depedency error, some required libraries not installed:"
  echo $T
  echo "Installation terminated"
  exit
fi

T=`ldd $D/ccsv5/common/uscif/libjscsauris.so | grep "not found"`
if [ -n "$T" ]; then
  echo "Depedency error, some required libraries not installed:"
  echo $T
  echo "Installation terminated"
  exit
fi

T=`ldd $D/opt/sauris/tcl/lib/tcl8.5/xds1.0/libtclxds.so | grep "not found"`
if [ -n "$T" ]; then
  echo "Depedency error, some required libraries not installed:"
  echo $T
  echo "Installation terminated"
  exit
fi


echo "Installing binaries (to /opt/sauris)"
cp -Rf $D/opt/sauris /opt

if [ "$?" != "0" ]; then
  echo "Installing binaries failed"
  echo "Installation terminated"
  exit
fi

echo "Adding startup scripts to /etc/profile.d"
cp -f $D/etc/profile.d/* /etc/profile.d/

if [ "$?" != "0" ]; then
  echo "Installing startup scripts failed"
  echo "Installation terminated"
  exit
fi

echo "Installing udev rules file"

which udevinfo >/dev/null 2>/dev/null
if [ "$?" != "0" ]; then
  which udevadm >/dev/null 2>/dev/null
  if [ "$?" != "0" ]; then
    echo "No 'udevinfo' or 'udevadm info' commands"
    echo "Installation terminated"
    exit
  fi
  UINFO="udevadm info"
else
  UINFO="udevinfo"
fi

U="/etc/udev/rules.d"

if [ ! -d "$U" ]; then
  echo "Directory with udev rules not exist"
  echo "Installation terminated"
  exit
fi

P=`$UINFO -e | grep P: | head -n 1 | sed -e "s/P: //"`

if [ -z "$P" ]; then
  echo "Can not determine udev's SYSFS/ATTR usage"
  echo "Installation terminated"
  exit
fi

P=`$UINFO -a -p $P | grep SYSFS`

if [ -z "$P" ]; then
  echo "Your udev uses ATTRS keyword in rules"
  cat $D/etc/udev/rules.d/71-sauris.rules | sed -e s/SYSFS/ATTRS/g > $U/71-sauris.rules
else
  echo "Your udev uses SYSFS keyword in rules"
  cat $D/etc/udev/rules.d/71-sauris.rules > $U/71-sauris.rules
fi

echo "Created udev rules file $U/71-sauris.rules"

OK=0
while [ "$OK" == "0" ]; do
  echo "Now installer attempts to find CCS installation"
  read -e -p "Enter path, where TI Code Composer Studio installed [/opt] :" C
  OK=1
  
  if [ -z "$C" ]; then
    C="/opt"
  fi
  
  echo "Searching for CCS DebugServer"
  C=`find $C -name 'ccs_base*' -type d -print -quit`

  if [ -z "$C" ]; then
     OK=0
  else
     if [ ! -d "$C/common/uscif" ]; then
       OK=0
     else
       if [ ! -d "$C/common/targetdb" ]; then
         OK=0
       fi
     fi
  fi

  if [ "$OK" == "1" ]; then
    echo "CCS Debug server found at $C"
  else
    echo "CCS Debug server NOT FOUND. Try again."
  fi
done

echo "Installing drivers into TI CCS"

cp -Rf $D/ccsv5/common $C/

if [ "$?" != "0" ]; then
  echo "Installing drivers failed"
  echo "Installation terminated"
  exit
fi

P=`cat $C/common/uscif/xdserror.cfg | grep offset_swd`
if [ -z "$P" ]; then
  echo "Emulation package before 5.1.340.0 detected"
else
  PWD = `pwd`
  cd $C/common/uscif/
  echo "Emulation package 5.1.340.0 or later detected"
  rm -f libjscsauris.so
  rm -f libjscsauris.so.0
  ln -s libjscsauris_340.so.0.0.0 libjscsauris.so
  ln -s libjscsauris_340.so.0.0.0 libjscsauris.so.0
  cd $PWD
fi

echo "Installation complete!"

